@@ -5,7 +5,7 @@
 
 BEGIN { $| = 1; print "1..1\n"; }
 END {print "not ok 1\n" unless $loaded;}
-use Term::Slang;
+use Term::Slang qw(:all);
 $loaded = 1;
 print "ok 1\n";
 
